@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moose;
 use namespace::autoclean;
@@ -44,7 +44,7 @@ Dist::Zilla::Plugin::Code::InstallTool - something that creates an install progr
 
 =head1 VERSION
 
-Version 0.004
+Version 0.005
 
 =head1 SYNOPSIS
 
@@ -100,11 +100,6 @@ Version 0.004
 
 This plugin implements the L<Dist::Zilla::Role::InstallTool> role.
 
-B<Note:> Because of the way L<Config::MVP> processes the arguments you have
-to put the sub reference inside an array reference. Otherwise you get an
-I<Not an ARRAY reference> error. See
-L<https://github.com/rjbs/Config-MVP/issues/13>.
-
 =head1 SUPPORT
 
 =head2 Bugs / Feature Requests
